#!/usr/bin/env python

from distutils.core import setup, Extension, Distribution
import distutils.sysconfig
import sys
import os.path
from translate import __version__
try:
  import py2exe
except ImportError:
  py2exe = None

join = os.path.join

translateversion = __version__.ver

packagesdir = distutils.sysconfig.get_python_lib()
sitepackages = packagesdir.replace(sys.prefix + os.sep, '')

packages = []

setuppackages = packages
# TODO: make these end with .py ending on Windows...
scripts = ["ooswitchlang"]
ext_modules = []

def buildmanifest_in(file, scripts):
  """This writes the required files to a MANIFEST.in file"""
  print >>file, "# MANIFEST.in: the below autogenerated by oo-switchlangsetup.py from translate %s" % translateversion
  print >>file, "# things needed by translate oo-switchlangsetup.py to rebuild"
  print >>file, "include MANIFEST.in"
  print >>file, "# informational files"
  for filename in ("README", "TODO", "ChangeLog", "COPYING", "*.txt"):
    print >>file, "global-include %s" % filename
  print >>file, "# C programs"
  print >>file, "global-include *.c"
  print >> file, "# scripts which don't get included by default in sdist"
  for scriptname in scripts:
    print >>file, "include %s" % scriptname
  print >>file, "# MANIFEST.in: the above autogenerated by oo-switchlangsetup.py from translate %s" % translateversion

class TranslateDistribution(Distribution):
  """a modified distribution class for translate"""
  def __init__(self, attrs):
    baseattrs = {}
    py2exeoptions = {}
    py2exeoptions["packages"] = ["encodings"]
    py2exeoptions["excludes"] = ["translate.portal"]
    py2exeoptions["compressed"] = True
    version = attrs.get("version", translateversion)
    py2exeoptions["dist_dir"] = "ooswitchlang-%s" % version
    options = {"py2exe": py2exeoptions}
    baseattrs['options'] = options
    if py2exe:
      self.com_server = []
      self.service = []
      self.windows = []
      self.console = ["ooswitchlang"]
      self.zipfile = "ooswitchlang.zip"
    baseattrs.update(attrs)
    Distribution.__init__(self, baseattrs)

def standardsetup(name, version, custompackages=[], customdatafiles=[]):
  manifest_in = open("MANIFEST.in", "w")
  buildmanifest_in(manifest_in, scripts)
  manifest_in.close()
  dosetup(name, version, setuppackages + custompackages, customdatafiles)

def dosetup(name, version, packages, datafiles):
  setup(name=name,
        version=version,
        description="oo language switcher",
        author="translate.sourceforge.net",
        author_email="translate-devel@lists.sourceforge.net",
        url="http://translate.sourceforge.net/",
        packages=packages,
        data_files=datafiles,
        scripts=scripts,
        ext_modules=ext_modules,
        distclass=TranslateDistribution
        )

if __name__ == "__main__":
  standardsetup("ooswitchlang", translateversion)

